@@ -2,19 +2,19 @@ package Catmandu::Fix::Condition::is_number;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.10';
+our $VERSION = '1.2024';
 
 use Moo;
+use Catmandu::Util qw(is_number);
 use namespace::clean;
 use Catmandu::Fix::Has;
 
 has path => (fix_arg => 1);
 
-with 'Catmandu::Fix::Condition::SimpleAllTest';
+with 'Catmandu::Fix::Condition::Builder::Simple';
 
-sub emit_test {
-    my ($self, $var) = @_;
-    "is_number(${var})";
+sub _build_value_tester {
+    \&is_number;
 }
 
 1;
