@@ -2,29 +2,32 @@ package Catmandu::Fix::Condition::valid;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.07';
+our $VERSION = '1.2024';
 
 use Moo;
 use Catmandu::Util qw(require_package);
 use namespace::clean;
 use Catmandu::Fix::Has;
 
-has path      => (fix_arg => 1);
-has name      => (fix_arg => 1);
-has opts      => (fix_opt => 'collect');
-has validator => (is      => 'lazy', init_arg => undef);
+has path           => (fix_arg => 1);
+has name           => (fix_arg => 1);
+has validator_opts => (fix_opt => 'collect');
+has validator      => (is      => 'lazy', init_arg => undef);
 
-with 'Catmandu::Fix::Condition::SimpleAllTest';
+with 'Catmandu::Fix::Condition::Builder::Simple';
 
-sub emit_test {
-    my ($self, $var, $fixer) = @_;
-    my $validator_var = $fixer->capture($self->validator);
-    "${validator_var}\->is_valid(${var})";
+sub _build_value_tester {
+    my ($self) = @_;
+    my $validator = $self->validator;
+    sub {
+        $validator->is_valid($_[0]);
+    }
 }
 
 sub _build_validator {
     my ($self) = @_;
-    require_package($self->name, 'Catmandu::Validator')->new($self->opts);
+    require_package($self->name, 'Catmandu::Validator')
+        ->new($self->validator_opts);
 }
 
 1;
@@ -49,6 +52,6 @@ Catmandu::Fix::Condition::valid - Execute fixes if the data passes validation
 
 =head1 SEE ALSO
 
-L<Catmandu::Fix>
+See L<Catmandu::Fix::validate> to check and get validation errors.
 
 =cut
