@@ -2,26 +2,21 @@ package Catmandu::Fix::add_field;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.9505';
+our $VERSION = '1.2024';
 
 use Moo;
+use Catmandu::Util::Path qw(as_path);
 use namespace::clean;
 use Catmandu::Fix::Has;
 
-with 'Catmandu::Fix::Base';
+with 'Catmandu::Fix::Builder';
 
 has path  => (fix_arg => 1);
-has value => (fix_arg => 1);
+has value => (fix_arg => 1, default => sub {undef});
 
-sub emit {
-    my ($self, $fixer) = @_;
-    my $path = $fixer->split_path($self->path);
-    my $value = $fixer->emit_value($self->value);
-
-    $fixer->emit_create_path($fixer->var, $path, sub {
-        my $var = shift;
-        "${var} = ${value};";
-    });
+sub _build_fixer {
+    my ($self) = @_;
+    as_path($self->path)->creator($self->value);
 }
 
 1;
@@ -50,6 +45,9 @@ if they are missing.
    # Create a deeply nested key
    add_field(my.deep.nested.key, hi)
 
+   # If the second argument is omitted the field has a null value
+   add_field(foo)
+
 =head1 SEE ALSO
 
 L<Catmandu::Fix>
