@@ -2,21 +2,22 @@ package Catmandu::Fix::append;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.07';
+our $VERSION = '1.2024';
 
 use Moo;
+use Catmandu::Util::Path qw(as_path);
 use namespace::clean;
 use Catmandu::Fix::Has;
 
 has path  => (fix_arg => 1);
 has value => (fix_arg => 1);
 
-with 'Catmandu::Fix::SimpleGetValue';
+with 'Catmandu::Fix::Builder';
 
-sub emit_value {
-    my ($self, $var, $fixer) = @_;
-    my $value = $fixer->emit_string($self->value);
-    "${var} = join('', ${var}, $value) if is_value(${var});";
+sub _build_fixer {
+    my ($self) = @_;
+    my $val = $self->value;
+    as_path($self->path)->updater(if_value => sub {join('', $_[0], $val)});
 }
 
 1;
