@@ -2,19 +2,20 @@ package Catmandu::Fix::array;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.10';
+our $VERSION = '1.2024';
 
 use Moo;
+use Catmandu::Util::Path qw(as_path);
 use namespace::clean;
 use Catmandu::Fix::Has;
 
+with 'Catmandu::Fix::Builder';
+
 has path => (fix_arg => 1);
 
-with 'Catmandu::Fix::SimpleGetValue';
-
-sub emit_value {
-    my ($self, $var) = @_;
-    "if (is_hash_ref(${var})) {" . "${var} = [\%{${var}}];" . "}";
+sub _build_fixer {
+    my ($self) = @_;
+    as_path($self->path)->updater(if_hash_ref => sub {[%{$_[0]}]});
 }
 
 1;
