@@ -2,11 +2,11 @@ package Catmandu::Fix::lookup;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.2012';
+our $VERSION = '1.2024';
 
 use Catmandu::Importer::CSV;
 use Catmandu::Util::Path qw(as_path);
-use Catmandu::Util qw(is_value);
+use Catmandu::Util       qw(is_value);
 use Moo;
 use namespace::clean;
 use Catmandu::Fix::Has;
@@ -101,6 +101,6 @@ looking up its value in a dictionary
 
 =head1 SEE ALSO
 
-L<Catmandu::Fix>
+L<Catmandu::Fix>, L<Catmandu::Fix::mapping>
 
 =cut
