@@ -2,9 +2,10 @@ package Catmandu::Importer;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.10';
+our $VERSION = '1.2024';
 
-use Catmandu::Util qw(io data_at is_value is_string is_array_ref is_hash_ref);
+use Catmandu::Util       qw(io is_value is_string is_array_ref is_hash_ref);
+use Catmandu::Util::Path qw(as_path);
 use LWP::UserAgent;
 use HTTP::Request ();
 use URI           ();
@@ -14,11 +15,13 @@ use namespace::clean;
 
 with 'Catmandu::Logger';
 with 'Catmandu::Iterable';
+with 'Catmandu::IterableOnce';
 with 'Catmandu::Fixable';
 with 'Catmandu::Serializer';
 
 around generator => sub {
     my ($orig, $self) = @_;
+
     my $generator = $orig->($self);
 
     if (my $fixer = $self->_fixer) {
@@ -26,13 +29,12 @@ around generator => sub {
     }
 
     if (defined(my $path = $self->data_path)) {
+        my $getter = as_path($path)->getter;
         return sub {
             state @buf;
             while (1) {
                 return shift @buf if @buf;
-
-                # TODO use something faster than data_at
-                @buf = data_at($path, $generator->() // return);
+                @buf = @{$getter->($generator->() // return)};
                 next;
             }
         };
@@ -44,20 +46,20 @@ around generator => sub {
 has file => (is => 'lazy', init_arg => undef);
 has _file_template =>
     (is => 'ro', predicate => 'has_file', init_arg => 'file');
-has variables => (is => 'ro', predicate => 1);
-has fh        => (is => 'ro', lazy      => 1, builder => 1);
-has encoding  => (is => 'ro', builder   => 1);
-has data_path            => (is => 'ro');
-has user_agent           => (is => 'ro');
-has http_method          => (is => 'lazy');
-has http_headers         => (is => 'lazy');
-has http_agent           => (is => 'ro', predicate => 1);
-has http_max_redirect    => (is => 'ro', predicate => 1);
-has http_timeout         => (is => 'ro', default => sub {180});  # LWP default
-has http_verify_hostname => (is => 'ro', default => sub {1});
-has http_retry  => (is => 'ro', predicate => 1);
-has http_timing => (is => 'ro', predicate => 1);
-has http_body   => (is => 'ro', predicate => 1);
+has variables         => (is => 'ro', predicate => 1);
+has fh                => (is => 'ro', lazy      => 1, builder => 1);
+has encoding          => (is => 'ro', builder   => 1);
+has data_path         => (is => 'ro');
+has user_agent        => (is => 'ro');
+has http_method       => (is => 'lazy');
+has http_headers      => (is => 'lazy');
+has http_agent        => (is => 'ro', predicate => 1);
+has http_max_redirect => (is => 'ro', predicate => 1);
+has http_timeout      => (is => 'ro', default   => sub {180});   # LWP default
+has http_verify_hostname => (is => 'ro', default   => sub {1});
+has http_retry           => (is => 'ro', predicate => 1);
+has http_timing          => (is => 'ro', predicate => 1);
+has http_body            => (is => 'ro', predicate => 1);
 has _http_client => (
     is       => 'ro',
     lazy     => 1,
@@ -131,7 +133,7 @@ sub _build_fh {
 
         my $content = $self->_http_request(
             $self->http_method, $file, $self->http_headers,
-            $body,              $self->_http_timing_tries,
+            $body, $self->_http_timing_tries,
         );
 
         return io(\$content, mode => 'r', binmode => $_[0]->encoding);
